@@ -1,9 +1,10 @@
 import datetime
 import json
 
-from cell import Cell
-from column import Column
-from table import Table
+from . import cell
+from . import column
+from . import table
+
 
 class Encoder(json.JSONEncoder):
     """
@@ -19,11 +20,11 @@ class Encoder(json.JSONEncoder):
                }
 
     def default(self, obj):
-        if isinstance(obj, Cell):
+        if isinstance(obj, cell.Cell):
             return dict(obj)
-        elif isinstance(obj, Column):
+        elif isinstance(obj, column.Column):
             return dict(obj)
-        elif isinstance(obj, Table):
+        elif isinstance(obj, table.Table):
             return dict(obj)
         t = type(obj)
         if t in self.formats:
@@ -35,4 +36,7 @@ class Encoder(json.JSONEncoder):
 
         return json.JSONEncoder.default(self, obj)
 
-encoder = Encoder()
+
+def encode(obj):
+    e = Encoder()
+    return e.encode(obj)
