@@ -1,7 +1,12 @@
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 
-from cell import Cell
-from column import Column
+import sys
+
+from .cell import Cell
+from .column import Column
 
 
 class Table(object):
@@ -13,6 +18,8 @@ class Table(object):
     Rows are ordered dictionaries mirroring columns.
     """
 
+    __gviz__version = 0.6
+
     def __init__(self, schema=None, options=None):
         """Sample schema
         ({'id':'name', 'type':'string', 'label':'Name', 'options':{} },
@@ -49,7 +56,8 @@ class Table(object):
         """
         Ensure that options are a dictionary
         """
-        assert isinstance(options, dict) or options is None, "Options must be a dictionary"
+        if options is not None and not isinstance(options, dict):
+            raise ValueError("Options must be a dictionary")
         self._options = options
 
     def _append(self, row):
@@ -80,8 +88,8 @@ class Table(object):
         Tuples do not have to be complete but will be exhausted in order, i.e.
         you can't have just a value and options.
         """
-        assert len(row) == len(self.schema), \
-               "Row length does not match number of columns"
+        if len(row) != len(self.schema):
+            raise ValueError("Row length does not match number of columns")
         self.rows.append(self._append(row))
 
     def extend(self, rows):
@@ -92,8 +100,28 @@ class Table(object):
     def __iter__(self):
         """Dictionary interface for JSON encoding"""
         rows = [{"c":r.values()} for r in self.rows]
-        cols = self.schema.values()
+        cols = list(self.schema.values())
         js = ['cols', 'rows', 'p']
         for k, v in zip(js, [cols, rows, self.options]):
             if v is not None:
                 yield k, v
+
+    def encode(self):
+        """
+        Convenience method for encoding tables
+        """
+        from .encoder import encode
+        return encode(self)
+
+    def source(self):
+        """
+        Convenience method for encoding a table as a static JSON data source.
+        This only wraps the table in the API.
+        """
+        from .encoder import encode
+        d = {}
+        d['status'] = "OK"
+        d['reqId'] = 0
+        d['version'] = self.__gviz__version
+        d['table'] = self
+        return  'google.visualization.Query.setResponse(%s)' % encode(d)
